@@ -7,6 +7,7 @@ from typing import Iterator
 
 import hypothesis
 import pytest
+from natsort.compat.locale import dumb_sort
 
 
 # This disables the "too slow" hypothesis heath check globally.
@@ -18,11 +19,8 @@ hypothesis.settings.register_profile(
 
 
 def load_locale(x: str) -> None:
-    """Convenience to load a locale, trying ISO8859-1 first."""
-    try:
-        locale.setlocale(locale.LC_ALL, str("{}.ISO8859-1".format(x)))
-    except locale.Error:
-        locale.setlocale(locale.LC_ALL, str("{}.UTF-8".format(x)))
+    """Convenience to load a locale."""
+    locale.setlocale(locale.LC_ALL, str("{}.UTF-8".format(x)))
 
 
 @pytest.fixture()
@@ -48,3 +46,21 @@ def with_locale_de_de() -> Iterator[None]:
         yield
     finally:
         locale.setlocale(locale.LC_ALL, orig)
+
+
+@pytest.fixture()
+def with_locale_cs_cz() -> Iterator[None]:
+    """
+    Convenience to load the cs_CZ locale - reset when complete - skip if missing.
+    """
+    orig = locale.getlocale()
+    try:
+        load_locale("cs_CZ")
+        if dumb_sort():
+            pytest.skip("requires a functioning locale library to run")
+    except locale.Error:
+        pytest.skip("requires cs_CZ locale to be installed")
+    else:
+        yield
+    finally:
+        locale.setlocale(locale.LC_ALL, orig)
