@@ -4,6 +4,7 @@ Here are a collection of examples of how this module can be used.
 See the README or the natsort homepage for more details.
 """
 
+import math
 from operator import itemgetter
 from pathlib import PurePosixPath
 from typing import List, Tuple, Union
@@ -110,19 +111,29 @@ def test_natsorted_handles_mixed_types(
 
 
 @pytest.mark.parametrize(
-    "alg, expected, slc",
+    "alg, expected",
     [
-        (ns.DEFAULT, [float("nan"), 5, "25", 1e40], slice(1, None)),
-        (ns.NANLAST, [5, "25", 1e40, float("nan")], slice(None, 3)),
+        (ns.DEFAULT, [float("nan"), None, float("-inf"), 5, "25", 1e40, float("inf")]),
+        (ns.NANLAST, [float("-inf"), 5, "25", 1e40, float("inf"), None, float("nan")]),
     ],
 )
-def test_natsorted_handles_nan(
-    alg: NSType, expected: List[Union[str, float, int]], slc: slice
+def test_natsorted_consistent_ordering_with_nan_and_friends(
+    alg: NSType, expected: List[Union[str, float, None, int]]
 ) -> None:
-    given: List[Union[str, float, int]] = ["25", 5, float("nan"), 1e40]
-    # The slice is because NaN != NaN
-    # noinspection PyUnresolvedReferences
-    assert natsorted(given, alg=alg)[slc] == expected[slc]
+    sentinel = math.pi
+    expected = [sentinel if x != x else x for x in expected]
+    given: List[Union[str, float, None, int]] = [
+        float("inf"),
+        float("-inf"),
+        "25",
+        5,
+        float("nan"),
+        1e40,
+        None,
+    ]
+    result = natsorted(given, alg=alg)
+    result = [sentinel if x != x else x for x in result]
+    assert result == expected
 
 
 def test_natsorted_with_mixed_bytes_and_str_input_raises_type_error() -> None:
@@ -367,3 +378,32 @@ def test_natsorted_sorts_mixed_ascii_and_non_ascii_numbers() -> None:
         "street ۱۲",
     ]
     assert natsorted(given, alg=ns.IGNORECASE) == expected
+
+
+def test_natsort_sorts_consistently_with_presort() -> None:
+    # Demonstrate the problem:
+    # Sorting is order-dependent for values that have different
+    # string representations are equiavlent numerically.
+    given = ["a01", "a1.4500", "a1", "a1.45"]
+    expected = ["a01", "a1", "a1.4500", "a1.45"]
+    result = natsorted(given, alg=ns.FLOAT)
+    assert result == expected
+
+    given = ["a1", "a1.45", "a01", "a1.4500"]
+    expected = ["a1", "a01", "a1.45", "a1.4500"]
+    result = natsorted(given, alg=ns.FLOAT)
+    assert result == expected
+
+    # The solution - use "presort" which will sort the
+    # input by its string representation before sorting
+    # with natsorted, which gives consitent results even
+    # if the numeric representation is identical
+    expected = ["a01", "a1", "a1.45", "a1.4500"]
+
+    given = ["a01", "a1.4500", "a1", "a1.45"]
+    result = natsorted(given, alg=ns.FLOAT | ns.PRESORT)
+    assert result == expected
+
+    given = ["a1", "a1.45", "a01", "a1.4500"]
+    result = natsorted(given, alg=ns.FLOAT | ns.PRESORT)
+    assert result == expected
